@@ -151,19 +151,19 @@
 //!
 //!   ```toml
 //!   [dependencies]
-//!   deadpool-postgres = { version = "0.7" }
+//!   deadpool-postgres = { version = "0.8" }
 //!   tokio-postgres = { version = "0.7", features = ["with-uuid-0_8"] }
 //!   ```
 //!
 //!   **Important:** The version numbers of `deadpool-postgres` and
-//!   `tokio-postgres` do not necessarily match. It is just a coincidence
-//!   that both crates have the same MAJOR and MINOR version number at the
-//!   time of this writing.
+//!   `tokio-postgres` do not necessarily match. If they do it is just a
+//!   coincidence that both crates have the same MAJOR and MINOR version
+//!   number.
 //!
 //! - **How can I clear the statement cache?**
 //!
 //!   You can call `pool.manager().statement_cache.clear()` to clear all
-//!   statement caches or `pool.manager().statement_cache.clear()` to remove
+//!   statement caches or `pool.manager().statement_cache.remove()` to remove
 //!   a single statement from all caches.
 //!
 //!   **Important:** The `ClientWrapper` also provides a `statement_cache`
@@ -235,7 +235,7 @@ impl<T: MakeTlsConnect<Socket>> Manager<T> {
         Self::from_config(pg_config, tls, ManagerConfig::default())
     }
     /// Create manager using a `tokio_postgres::Config` and a `TlsConnector`
-    /// and also
+    /// and `deadpool_postgres::ManagerConfig`.
     pub fn from_config(
         pg_config: tokio_postgres::Config,
         tls: T,
@@ -399,14 +399,14 @@ impl StatementCache {
             types: Cow::Owned(types.to_owned()),
         };
         let mut map = self.map.write().unwrap();
-        let removed = map.remove(&key).map(|stmt| stmt.to_owned());
+        let removed = map.remove(&key);
         if removed.is_some() {
             self.size.fetch_sub(1, Ordering::Relaxed);
         }
         removed
     }
     /// Get statement from cache
-    fn get<'a>(&self, query: &str, types: &[Type]) -> Option<Statement> {
+    fn get(&self, query: &str, types: &[Type]) -> Option<Statement> {
         let key = StatementCacheKey {
             query: Cow::Borrowed(query),
             types: Cow::Borrowed(types),
